OiRA

# Reporting

Now that you have finished identifying all the risks in your organisation and created an action plan you can create a report which lists all your results. You can, if desired, add some extra comments that should be included in this report in the field below.

Save and continue

Back

## report.html

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Loading Risk Assessments…